pub enum Addr {
Proc(ProcAddr),
Actor(ActorAddr),
Port(PortAddr),
}Expand description
A polymorphic reference: proc, actor, or port.
Used for prefix-based routing in [MailboxRouter] and
[DialMailboxRouter]. Ordering is lexicographic by
(proc, actor uid, port).
Variants
Proc(ProcAddr)
A process reference.
Actor(ActorAddr)
An actor reference.
Port(PortAddr)
A port reference.
Implementations
Sourceimpl Addr
impl Addr
Sourcepub fn as_proc_mut(&mut self) -> Option<&mut ProcAddr>
pub fn as_proc_mut(&mut self) -> Option<&mut ProcAddr>
Optionally returns mutable references to the inner fields if this is a Addr::Proc, otherwise None
Sourcepub fn as_proc(&self) -> Option<&ProcAddr>
pub fn as_proc(&self) -> Option<&ProcAddr>
Optionally returns references to the inner fields if this is a Addr::Proc, otherwise None
Sourcepub fn into_proc(self) -> Result<ProcAddr, Self>
pub fn into_proc(self) -> Result<ProcAddr, Self>
Returns the inner fields if this is a Addr::Proc, otherwise returns back the enum in the Err case of the result
Sourcepub fn as_actor_mut(&mut self) -> Option<&mut ActorAddr>
pub fn as_actor_mut(&mut self) -> Option<&mut ActorAddr>
Optionally returns mutable references to the inner fields if this is a Addr::Actor, otherwise None
Sourcepub fn as_actor(&self) -> Option<&ActorAddr>
pub fn as_actor(&self) -> Option<&ActorAddr>
Optionally returns references to the inner fields if this is a Addr::Actor, otherwise None
Sourcepub fn into_actor(self) -> Result<ActorAddr, Self>
pub fn into_actor(self) -> Result<ActorAddr, Self>
Returns the inner fields if this is a Addr::Actor, otherwise returns back the enum in the Err case of the result
Sourcepub fn as_port_mut(&mut self) -> Option<&mut PortAddr>
pub fn as_port_mut(&mut self) -> Option<&mut PortAddr>
Optionally returns mutable references to the inner fields if this is a Addr::Port, otherwise None