pub struct ActorAddr { /* private fields */ }Expand description
An actor identifier paired with a network location.
Implementations
Sourceimpl ActorAddr
impl ActorAddr
Sourcepub fn new_from_uid(proc_ref: ProcAddr, uid: Uid) -> Self
pub fn new_from_uid(proc_ref: ProcAddr, uid: Uid) -> Self
Create an ActorAddr from a ProcAddr and actor uid.
Sourcepub fn addr(&self) -> &ChannelAddr
pub fn addr(&self) -> &ChannelAddr
The actor’s channel address.
Sourcepub fn label(&self) -> Option<&Label>
pub fn label(&self) -> Option<&Label>
The actor’s label: explicit metadata label for instances, or singleton name for singletons.
Sourcepub fn root(proc_ref: ProcAddr, label: impl Into<Label>) -> Self
pub fn root(proc_ref: ProcAddr, label: impl Into<Label>) -> Self
Create an ActorAddr for a root actor on a proc.
Sourcepub fn anonymous_child(&self) -> Self
pub fn anonymous_child(&self) -> Self
Create an ActorAddr for a child actor with a random uid.