pub struct PortAddr { /* private fields */ }Expand description
A port identifier paired with a network location.
Implementations
Sourceimpl PortAddr
impl PortAddr
Sourcepub fn actor_addr(&self) -> ActorAddr
pub fn actor_addr(&self) -> ActorAddr
Reconstruct the parent ActorAddr (with location preserved).
Sourcepub fn actor_ref(&self) -> ActorAddr
pub fn actor_ref(&self) -> ActorAddr
Reconstruct the parent ActorAddr (with location preserved).
Sourcepub fn send(&self, cx: &impl Actor, serialized: Any)
pub fn send(&self, cx: &impl Actor, serialized: Any)
Send a serialized message to this port, provided a sending capability.
Sourcepub fn send_with_headers(
&self,
cx: &impl Actor,
serialized: Any,
headers: Flattrs,
)
pub fn send_with_headers( &self, cx: &impl Actor, serialized: Any, headers: Flattrs, )
Send a serialized message with explicit headers.
Sourcepub fn split(
&self,
cx: &impl Actor,
reducer_spec: Option<ReducerSpec>,
reducer_mode: ReducerMode,
return_undeliverable: bool,
) -> Result<PortAddr>
pub fn split( &self, cx: &impl Actor, reducer_spec: Option<ReducerSpec>, reducer_mode: ReducerMode, return_undeliverable: bool, ) -> Result<PortAddr>
Split this port through a local proxy, possibly reducing messages.