pub struct ProcAddr { /* private fields */ }Expand description
A process identifier paired with a network location.
Implementations
Sourceimpl ProcAddr
impl ProcAddr
Sourcepub fn addr(&self) -> &ChannelAddr
pub fn addr(&self) -> &ChannelAddr
The proc’s channel address.
Sourcepub fn label(&self) -> Option<&Label>
pub fn label(&self) -> Option<&Label>
The proc’s label: the explicit metadata label for instances, or the singleton name for singletons.
Sourcepub fn anonymous(addr: ChannelAddr) -> Self
pub fn anonymous(addr: ChannelAddr) -> Self
Create a ProcAddr with an anonymous instance proc id.
Sourcepub fn instance(addr: ChannelAddr, base_name: impl AsRef<str>) -> Self
pub fn instance(addr: ChannelAddr, base_name: impl AsRef<str>) -> Self
Create a ProcAddr with an instance proc id and the given display label.
Sourcepub fn singleton(addr: ChannelAddr, name: impl AsRef<str>) -> Self
pub fn singleton(addr: ChannelAddr, name: impl AsRef<str>) -> Self
Create a ProcAddr with a singleton proc id identified by the given name.
Sourcepub fn actor_addr(&self, name: impl AsRef<str>) -> ActorAddr
pub fn actor_addr(&self, name: impl AsRef<str>) -> ActorAddr
Create an ActorAddr singleton with the provided name within this proc.
Sourcepub fn actor_addr_uid(&self, uid: Uid) -> ActorAddr
pub fn actor_addr_uid(&self, uid: Uid) -> ActorAddr
Create an ActorAddr with the provided uid within this proc.